@@ -31,13 +31,14 @@ import logging
 from threading import Timer
 from binascii import b2a_hex, a2b_hex
 from .util import (
-    click_force_option, click_skip_on_help,
-    click_callback, click_parse_b32_key,
-    prompt_for_touch, UpperCaseChoice)
+    click_force_option, click_postpone_execution, click_callback,
+    click_parse_b32_key, prompt_for_touch, UpperCaseChoice
+)
 from ..driver_ccid import (
-    APDUError,  SW_APPLICATION_NOT_FOUND, SW_SECURITY_CONDITION_NOT_SATISFIED)
+    APDUError,  SW
+)
 from ..util import TRANSPORT, parse_b32_key
-from ..oath import OathController, SW, CredentialData, OATH_TYPE, ALGO
+from ..oath import OathController, CredentialData, OATH_TYPE, ALGO
 from ..settings import Settings
 
 
@@ -80,19 +81,33 @@ def click_parse_uri(ctx, param, val):
 
 @click.group()
 @click.pass_context
-@click_skip_on_help
+@click_postpone_execution
 @click.option('-p', '--password', help='Provide a password to unlock the '
               'YubiKey.')
 def oath(ctx, password):
     """
     Manage OATH Application.
+
+    Examples:
+
+    \b
+      Generate codes for credentials starting with 'yubi':
+      $ ykman oath code yubi
+
+    \b
+      Add a touch credential with the secret key f5up4ub3dw and the name yubico:
+      $ ykman oath add yubico f5up4ub3dw --touch
+
+    \b
+      Set a password for the OATH application:
+      $ ykman oath set-password
     """
     try:
         controller = OathController(ctx.obj['dev'].driver)
         ctx.obj['controller'] = controller
         ctx.obj['settings'] = Settings('oath')
     except APDUError as e:
-        if e.sw == SW_APPLICATION_NOT_FOUND:
+        if e.sw == SW.NOT_FOUND:
             ctx.fail("The OATH application can't be found on this YubiKey.")
         raise
 
@@ -135,14 +150,16 @@ def reset(ctx):
     the OATH application on the YubiKey.
     """
 
+    controller = ctx.obj['controller']
     click.echo('Resetting OATH data...')
-    old_id = ctx.obj['controller'].id
-    ctx.obj['controller'].reset()
+    old_id = controller.id
+    controller.reset()
 
-    keys = ctx.obj['settings'].setdefault('keys', {})
+    settings = ctx.obj['settings']
+    keys = settings.setdefault('keys', {})
     if old_id in keys:
         del keys[old_id]
-        ctx.obj['settings'].write()
+        settings.write()
 
     click.echo(
         'Success! All OATH credentials have been cleared from your YubiKey.')
@@ -186,13 +203,12 @@ def add(ctx, secret, name, issuer, period, oath_type, digits, touch, algorithm,
 
     if not secret:
         while True:
-            secret = click.prompt('Enter a secret key (base32)')
+            secret = click.prompt('Enter a secret key (base32)', err=True)
             try:
                 secret = parse_b32_key(secret)
                 break
             except Exception as e:
                 click.echo(e)
-                pass
 
     ensure_validated(ctx)
 
@@ -214,13 +230,12 @@ def uri(ctx, uri, touch, force):
 
     if not uri:
         while True:
-            uri = click.prompt('Enter an OATH URI')
+            uri = click.prompt('Enter an OATH URI', err=True)
             try:
                 uri = CredentialData.from_uri(uri)
                 break
             except Exception as e:
                 click.echo(e)
-                pass
 
     ensure_validated(ctx)
     data = uri
@@ -236,7 +251,6 @@ def uri(ctx, uri, touch, force):
 
 
 def _add_cred(ctx, data, force):
-
     controller = ctx.obj['controller']
 
     if not (0 < len(data.name) <= 64):
@@ -259,7 +273,8 @@ def _add_cred(ctx, data, force):
     if not force and any(cred.key == key for cred in controller.list()):
         click.confirm(
             'A credential called {} already exists on this YubiKey.'
-            ' Do you want to overwrite it?'.format(data.name), abort=True)
+            ' Do you want to overwrite it?'.format(data.name), abort=True,
+            err=True)
 
     firmware_overwrite_issue = (4, 0, 0) < controller.version < (4, 3, 5)
     cred_is_subset = any(
@@ -305,7 +320,7 @@ def list(ctx, show_hidden, oath_type, period):
     for cred in creds:
         click.echo(cred.printable_key, nl=False)
         if oath_type:
-            click.echo(', {}'.format(cred.oath_type.name), nl=False)
+            click.echo(u', {}'.format(cred.oath_type.name), nl=False)
         if period:
             click.echo(', {}'.format(cred.period), nl=False)
         click.echo()
@@ -351,7 +366,7 @@ def code(ctx, show_hidden, query, single):
             elif code is None:
                 creds = [(cred, controller.calculate(cred))]
         except APDUError as e:
-            if e.sw == SW_SECURITY_CONDITION_NOT_SATISFIED:
+            if e.sw == SW.SECURITY_CONDITION_NOT_SATISFIED:
                 ctx.fail('Touch credential timed out!')
 
     elif single:
@@ -374,7 +389,7 @@ def code(ctx, show_hidden, query, single):
 
         longest_name = max(len(n) for (n, c) in outputs) if outputs else 0
         longest_code = max(len(c) for (n, c) in outputs) if outputs else 0
-        format_str = '{:<%d}  {:>%d}' % (longest_name, longest_code)
+        format_str = u'{:<%d}  {:>%d}' % (longest_name, longest_code)
 
         for name, result in outputs:
             click.echo(format_str.format(name, result))
@@ -402,11 +417,11 @@ def delete(ctx, query, force):
     elif len(hits) == 1:
         cred = hits[0]
         if force or (click.confirm(
-                'Delete credential: {} ?'.format(cred.printable_key),
-                default=False
+                u'Delete credential: {} ?'.format(cred.printable_key),
+                default=False, err=True
         )):
             controller.delete(cred)
-            click.echo('Deleted {}.'.format(cred.printable_key))
+            click.echo(u'Deleted {}.'.format(cred.printable_key))
         else:
             click.echo('Deletion aborted by user.')
 
@@ -436,7 +451,8 @@ def set_password(ctx, new_password, remember):
         new_password = click.prompt(
             'Enter your new password',
             hide_input=True,
-            confirmation_prompt=True)
+            confirmation_prompt=True,
+            err=True)
 
     controller = ctx.obj['controller']
     settings = ctx.obj['settings']
@@ -498,7 +514,7 @@ def ensure_validated(ctx, prompt='Enter your password', remember=False):
                 del keys[controller.id]
 
         # Prompt for password
-        password = click.prompt(prompt, hide_input=True)
+        password = click.prompt(prompt, hide_input=True, err=True)
         key = controller.derive_key(password)
         _validate(ctx, key, remember)
 
