@@ -307,7 +307,7 @@ def kill_scdaemon():
     return killed
 
 
-def _list_readers():
+def list_readers():
     try:
         return System.readers()
     except ListReadersException:
@@ -319,11 +319,11 @@ def _list_readers():
 
 
 def open_devices(name_filter=YK_READER_NAME):
-    readers = _list_readers()
+    readers = list_readers()
     while readers:
         try_again = []
         for reader in readers:
-            if reader.name.lower().startswith(name_filter.lower()):
+            if name_filter.lower() in reader.name.lower():
                 try:
                     conn = reader.createConnection()
                     conn.connect()
