@@ -810,7 +810,7 @@ class PivController(object):
         id_bytes = struct.pack(b'>I', object_id).lstrip(b'\0')
         tlv = Tlv(self.send_cmd(INS.GET_DATA, 0x3f, 0xff,
                                 Tlv(TAG.OBJ_ID, id_bytes)))
-        if tlv.tag != TAG.OBJ_DATA:
+        if tlv.tag not in [TAG.OBJ_DATA, OBJ.DISCOVERY]:
             raise ValueError('Wrong tag in response data!')
         return tlv.value
 
@@ -912,7 +912,8 @@ class PivController(object):
         self.send_cmd(INS.IMPORT_KEY, algorithm, slot, data)
         return algorithm
 
-    def import_certificate(self, slot, certificate, verify=False):
+    def import_certificate(
+            self, slot, certificate, verify=False, touch_callback=None):
         cert_data = certificate.public_bytes(Encoding.DER)
 
         if verify:
@@ -922,9 +923,17 @@ class PivController(object):
                 public_key = certificate.public_key()
 
                 test_data = b'test'
+
+                if touch_callback is not None:
+                    touch_timer = Timer(0.500, touch_callback)
+                    touch_timer.start()
+
                 test_sig = self.sign(
                     slot, ALGO.from_public_key(public_key), test_data)
 
+                if touch_callback is not None:
+                    touch_timer.cancel()
+
                 if isinstance(public_key, rsa.RSAPublicKey):
                     public_key.verify(
                         test_sig, test_data, padding.PKCS1v15(),
